@@ -36,3 +36,8 @@ lisp::atom::recursive_mark(void) {
   set_mark(true);
   return 0;
 }
+
+const char *
+lisp::atom::get_typeof(void) const {
+  return "ATOM";
+}
