@@ -56,3 +56,8 @@ lisp::cons::recursive_mark(void) {
 
   return total;
 }
+
+const char *
+lisp::cons::get_typeof(void) const {
+  return "CONS";
+}
