@@ -22,12 +22,13 @@ namespace lisp {
   public:
     weak_object car, cdr;
 
-    cons(void) : variable("CONS") { }
-    cons(object a, object d) : variable("CONS"), car(a), cdr(d) { }
+    cons(void) { }
+    cons(object a, object d) : car(a), cdr(d) { }
 
     virtual string print(void) const;
     virtual bool equal(object) const;
     virtual int recursive_mark(void);
+    virtual const char *get_typeof(void) const;
   };
 
   inline cons& assume_cons(object o) { return *(cons *)(o.get_data()); }
