@@ -20,8 +20,8 @@
 namespace lisp {
   class function : public variable {
   public:
-    function(void) : variable("FUNCTION") { }
     virtual object funcall(library&, int, object *)=0;
+    virtual const char *get_typeof(void) const;
   };
 
   inline bool is_function(const object o) {
