@@ -38,3 +38,8 @@ lisp::str::recursive_mark(void) {
   set_mark(true);
   return 1;
 }
+
+const char *
+lisp::str::get_typeof(void) const {
+  return "STRING";
+}
