@@ -20,7 +20,7 @@
 namespace lisp {
   class str : public variable {
   public:
-    str(const char *what) : variable("STRING"), data(what) { }
+    str(const char *what) : data(what) { }
 
     const char *get_text(void) const { return data.c_str(); }
     void set_text(const char *what) { data=what; }
@@ -28,6 +28,7 @@ namespace lisp {
     virtual string print(void) const;
     virtual bool equal(object) const;
     virtual int recursive_mark(void);
+    virtual const char *get_typeof(void) const;
 
   private:
     string data;
