@@ -19,7 +19,7 @@
 
 int lisp::variable::total=0;
 
-lisp::variable::variable(const char *t) : count(0), type_of(t) {
+lisp::variable::variable(void) : count(0) {
   if(total++>=16384) {
     gc();
     total=0;
