@@ -20,12 +20,13 @@
 namespace lisp {
   class variable {
   public:
-    variable(const char *);
+    variable(void);
     virtual ~variable(void);
 
     virtual string print(void) const=0;
     virtual bool equal(object) const=0;
     virtual int recursive_mark(void)=0;
+    virtual const char *get_typeof(void) const=0;
 
     bool get_mark(void) const { return gc_mark; }
     void set_mark(bool m) { gc_mark=m; }
@@ -34,12 +35,9 @@ namespace lisp {
     void add_reference(void) { count++; }
     void remove_reference(void) { count--; }
 
-    const char *get_typeof(void) const { return type_of; }
-
   private:
     int count;
     bool gc_mark;
-    const char *type_of;
 
     static int total;
   };
